@@ -14,30 +14,28 @@ except LookupError:
 
 wn = wordnet.WordNetCorpusReader(wordnet_path)
 
-try:
-    from idf_scores import scores as IDF
-except ImportError:
-    IDF = get_idf_scores()
+def reduce_sense(sense):
+    bag = set(re.findall(r'\b[A-Za-z]+\b',sense.definition.lower()))
+    #for x in sense.lemmas:
+    #    bag.update(re.findall(r'\b[A-Za-z]+\b',x.name.lower()))
+    for e in sense.examples:
+        bag.update(re.findall(r'\b[A-Za-z]+\b',e.lower()))
+    return bag
 
 def get_idf_scores():
     scores = Counter()
     for s in wn.all_synsets():
-        bag = set(re.findall(r'\b[A-Za-z]+\b',s.definition.lower()))
-        for e in s.examples:
-            bag.update(re.findall(r'\b[A-Za-z]+\b',e.lower()))
-        scores.update(bag)
+        scores.update(reduce_sense(s))
     tot_count = float(len(list(wn.all_synsets())))
     for k in scores:
         scores[k] = -1 * math.log(float(scores[k])/tot_count)
     return scores
 
-def reduce_sense(sense):
-    bag = set(re.findall(r'\b[A-Za-z]+\b',sense.definition.lower()))
-    for x in sense.lemmas:
-        bag.update(re.findall(r'\b[A-Za-z]+\b',x.name.lower()))
-    for e in sense.examples:
-        bag.update(re.findall(r'\b[A-Za-z]+\b',e.lower()))
-    return bag
+try:
+    from idf_scores import scores as IDF
+except ImportError:
+    IDF = get_idf_scores()
+
 
 def bag_of_words(sense):
     bag = reduce_sense(sense)
